@@ -48,8 +48,6 @@ class Project(object):
     },
     'ENGINE': {
       'URL': 'sqlite://',
-      'POOL_RECYCLE': 3600,
-      'CONVERT_UNICODE': True,
     },
     'APP': {
       'SECRET_KEY': 'a_default_unsafe_key',
@@ -111,17 +109,7 @@ class Project(object):
     for mod in project_modules:
       __import__(mod.strip())
     # database
-    engine_ops = dict((k.lower(), v) for k,v in self.config['ENGINE'].items())
-    self._engine = create_engine(engine_ops.pop('url'), **engine_ops)
-    self.session = scoped_session(sessionmaker(bind=self._engine))
-    if app:
-      @self.app.teardown_request
-      def teardown_request_handler(exception=None):
-        self._dismantle_database_connections()
-    if celery:
-      @task_postrun.connect
-      def task_postrun_handler(*args, **kwargs):
-        self._dismantle_database_connections()
+    self._setup_database_connection(app, celery)
     # extensions
     for extension, config_section in self._extensions or []:
       if config_section:
@@ -134,6 +122,19 @@ class Project(object):
     for func in self._before_startup or []:
       func(self)
 
+  def _setup_database_connection(self, app, celery):
+    engine_ops = dict((k.lower(), v) for k,v in self.config['ENGINE'].items())
+    self._engine = create_engine(engine_ops.pop('url'), **engine_ops)
+    self.session = scoped_session(sessionmaker(bind=self._engine))
+    if app:
+      @self.app.teardown_request
+      def teardown_request_handler(exception=None):
+        self._dismantle_database_connections()
+    if celery:
+      @task_postrun.connect
+      def task_postrun_handler(*args, **kwargs):
+        self._dismantle_database_connections()
+
   def _dismantle_database_connections(self, **kwrds):
     """Remove database connections.
 
